@@ -1,6 +1,6 @@
 /*
 goredo -- djb's redo implementation on pure Go
-Copyright (C) 2020-2022 Sergey Matveev <stargrave@stargrave.org>
+Copyright (C) 2020-2023 Sergey Matveev <stargrave@stargrave.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -55,6 +55,7 @@ const (
 	CmdNameRedoTargets  = "redo-targets"
 	CmdNameRedoWhichdo  = "redo-whichdo"
 	CmdNameRedoDepFix   = "redo-depfix"
+	CmdNameRedoInode    = "redo-inode"
 )
 
 var (
@@ -502,6 +503,20 @@ CmdSwitch:
 		}
 	case CmdNameRedoDepFix:
 		err = depFix(Cwd)
+	case CmdNameRedoInode:
+		var inode *Inode
+		for _, tgt := range tgts {
+			inode, err = inodeFromFileByPath(tgt)
+			if err != nil {
+				break
+			}
+			err = recfileWrite(os.Stdout, append(
+				[]recfile.Field{{Name: "Target", Value: tgt}},
+				inode.RecfileFields()...)...)
+			if err != nil {
+				break
+			}
+		}
 	default:
 		log.Fatalln("unknown command", cmdName)
 	}
